//@line 36 "/builds/slave/release-mozilla-1.9.1-linux_repack_2/build/l10n-mozilla-1.9.1/eo/browser/firefox-l10n.js"

//@line 38 "/builds/slave/release-mozilla-1.9.1-linux_repack_2/build/l10n-mozilla-1.9.1/eo/browser/firefox-l10n.js"

pref("general.useragent.locale", "eo");
